==> wesnoth-1.14_1.14.5.orig.tar.bz2: wesnoth-1.14.5/README.md <==
[![Build Status](https://travis-ci.org/wesnoth/wesnoth.svg?branch=1.14)](https://travis-ci.org/wesnoth/wesnoth)
[![Build status](https://ci.appveyor.com/api/projects/status/nv5jnof3lk3j6kg6?svg=true)](https://ci.appveyor.com/project/wesnoth/wesnoth)
[![License: GPL v2](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)
[![Coverity Scan](https://img.shields.io/coverity/scan/1063.svg)](https://scan.coverity.com/projects/wesnoth)

About
=====

**The Battle for Wesnoth** is an Open Source, turn-based tactical strategy game with a
high fantasy theme, featuring both singleplayer and online/hotseat multiplayer
combat. Fight a desperate battle to reclaim the throne of Wesnoth, or take
hand in any number of other adventures.


License
-------

Please see the wiki for information regarding The Battle for Wesnoth's licensing:

  <https://wiki.wesnoth.org/Wesnoth:Copyrights>


Installing
----------

See INSTALL.md for instructions on how to build the game from source code.


More Information
----------------

For extensive documentation about all aspects of the game, see the
official Battle for Wesnoth web site.

  <https://www.wesnoth.org/>

A (translated) description of how to play the game can be found in
doc/manual/manual.*.html, or online at:

  <https://wiki.wesnoth.org/WesnothManual>

The official Battle for Wesnoth Forums (with over 400,000 posts from more than
20,000 registered members) can be found at:

  <https://forums.wesnoth.org/>

==> wesnoth-1.14_1.14.9.orig.tar.bz2: wesnoth-1.14.9/README.md <==
[![Build Status](https://travis-ci.org/wesnoth/wesnoth.svg?branch=1.14)](https://travis-ci.org/wesnoth/wesnoth)
[![Build status](https://ci.appveyor.com/api/projects/status/github/wesnoth/wesnoth?branch=1.14&svg=true)](https://ci.appveyor.com/account/wesnoth/projects)
[![License: GPL v2](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)
[![Coverity Scan](https://img.shields.io/coverity/scan/1063.svg)](https://scan.coverity.com/projects/wesnoth)

About
=====

**The Battle for Wesnoth** is an Open Source, turn-based tactical strategy game with a
high fantasy theme, featuring both singleplayer and online/hotseat multiplayer
combat. Fight a desperate battle to reclaim the throne of Wesnoth, or take
hand in any number of other adventures.


License
-------

Please see the wiki for information regarding The Battle for Wesnoth's licensing:

  <https://wiki.wesnoth.org/Wesnoth:Copyrights>


Installing
----------

See INSTALL.md for instructions on how to build the game from source code.


More Information
----------------

For extensive documentation about all aspects of the game, see the
official Battle for Wesnoth web site.

  <https://www.wesnoth.org/>

A (translated) description of how to play the game can be found in
doc/manual/manual.*.html, or online at:

  <https://wiki.wesnoth.org/WesnothManual>

The official Battle for Wesnoth Forums (with over 400,000 posts from more than
20,000 registered members) can be found at:

  <https://forums.wesnoth.org/>
